@@ -10,8 +10,10 @@ Assura rules etc. This parser may parse invalid SKILL scripts.
 import re
 from collections import OrderedDict
 
+
 __all__ = ["SkillFile"]
 
+
 from modgrammar import (
     Grammar, L, NOT_FOLLOWED_BY, WORD, REF, OPTIONAL, WHITESPACE, ZERO_OR_MORE, ONE_OR_MORE,
 )
@@ -86,6 +88,7 @@ class SkillContext:
 
         self.procedures.update(procedures)
 
+
 class SkillInterpreter:
     def __init__(self):
         self.callbacks = {
@@ -158,7 +161,7 @@ class SkillInterpreter:
                 try:
                     func, kwargs = self.callbacks[key]
                 except KeyError:
-                    ret = "FUNCCALL:{}".format(key)
+                    ret = f"FUNCCALL:{key}"
                 else:
                     ret = func(context, body, **kwargs)
 
@@ -195,6 +198,7 @@ class SkillInterpreter:
             
         return self(args["statements"], context=subcontext)
 
+
 #
 # SKILL builtin functions
 #
@@ -204,6 +208,7 @@ def _skill_let(elems, **kwargs):
         "statements": elems[1],
     }
 
+
 def _skill_for(elems, **kwargs):
     assert len(elems) > 3
     return {
@@ -213,6 +218,7 @@ def _skill_for(elems, **kwargs):
         "statements": elems[3:],
     }
 
+
 def _skill_foreach(elems, **kwargs):
     assert len(elems) > 2
     return {
@@ -221,6 +227,7 @@ def _skill_foreach(elems, **kwargs):
         "statements": elems[2:],
     }
 
+
 def _skill_if(elems, **kwargs):
     thenidx = None
     elseidx = None
@@ -248,6 +255,7 @@ def _skill_if(elems, **kwargs):
 
     return value
 
+
 def _skill_when(elems, **kwargs):
     assert len(elems) > 1
     cond = elems[0]
@@ -259,6 +267,7 @@ def _skill_when(elems, **kwargs):
         "then": elems[1:],
     }
 
+
 def _skill_functionlist(elems, **kwargs):
     """A list of functions with value converted to a dict with the function names as keys"""
     
@@ -269,6 +278,7 @@ def _skill_functionlist(elems, **kwargs):
 
     return value
 
+
 _builtins = {
     "let": _skill_let,
     "prog": _skill_let, # Dont make distinction in return() handling
@@ -288,7 +298,8 @@ class _BaseGrammar(Grammar):
         if _debug:
             start = self._str_info[1]
             end = self._str_info[2]
-            print("{}: {}-{}".format(self.__class__.__name__, start, end))
+            print(f"{self.__class__.__name__}: {start}-{end}")
+
 
 class Symbol(_BaseGrammar):
     grammar = RE(r"'[a-zA-Z_][a-zA-Z0-9_]*")
@@ -297,6 +308,7 @@ class Symbol(_BaseGrammar):
         self.value = self.string[1:]
         self.ast = {"Symbol": self.value}
 
+
 class Bool(_BaseGrammar):
     grammar = L("t")|L("nil"), NOT_FOLLOWED_BY(WORD("a-zA-Z0-9_"))
 
@@ -304,6 +316,7 @@ class Bool(_BaseGrammar):
         self.value = self.string == "t"
         self.ast = {"Bool": self.value}
 
+
 class Identifier(_BaseGrammar):
     grammar = WORD("a-zA-Z_?@", "a-zA-Z0-9_?@."), NOT_FOLLOWED_BY(L("("))
 
@@ -311,6 +324,7 @@ class Identifier(_BaseGrammar):
         self.ast = {"Identifier": self.string}
         self.value = self.string
 
+
 class Number(_BaseGrammar):
     grammar = RE(r"(\+|\-)?([0-9]+(\.[0-9]*)?|\.[0-9]+)(e(\+|-)?[0-9]+)?")
 
@@ -319,6 +333,7 @@ class Number(_BaseGrammar):
         self.value = float(self.string) if isfloat else int(self.string)
         self.ast = {"Number": self.value}
 
+
 class String(_BaseGrammar):
     grammar = RE(r'"([^"\\]+|\\(.|\n))*"')
 
@@ -326,21 +341,26 @@ class String(_BaseGrammar):
         self.value = self.string
         self.ast = {"String": self.value}
 
+
 class SignSymbol(_BaseGrammar):
     # +/- followed by a digit
     grammar_whitespace_mode = "explicit"
     grammar = RE(r"[\+\-](?=[0-9])")
 
+
 class SignOperator(_BaseGrammar):
     # +/- not followed by a digit
     grammar = RE(r"[\+\-](?![\+\-0-9])")
 
+
 class PrefixOperator(_BaseGrammar):
     grammar = L("!") | RE(r"\+(?!\+)") | RE(r"\-(?!-)")
 
+
 class PostfixOperator(_BaseGrammar):
     grammar = L("++") | L("--")
 
+
 class BinaryOperator(_BaseGrammar):
     grammar = (
         L("=") | L(":") | L("<") | L(">") | L("<=") | L(">=") | L("==") | L("!=") | L("<>") |
@@ -350,9 +370,11 @@ class BinaryOperator(_BaseGrammar):
         L(",")
     )
 
+
 class FieldOperator(_BaseGrammar):
     grammar = L("->") | L("~>")
 
+
 class ItemBase(_BaseGrammar):
     grammar = (
         (
@@ -379,6 +401,7 @@ class ItemBase(_BaseGrammar):
         self.ast = {"ItemBase": ast}
         self.value = value
 
+
 class Item(_BaseGrammar):
     grammar_whitespace_mode = "optional"
     grammar = ZERO_OR_MORE(PrefixOperator), ItemBase, ZERO_OR_MORE(PostfixOperator)
@@ -403,6 +426,7 @@ class Item(_BaseGrammar):
         self.ast = {"Item": ast}
         self.value = value
 
+
 class Expression(_BaseGrammar):
     grammar_whitespace_mode = "optional"
     grammar = Item, ZERO_OR_MORE(BinaryOperator, Item)
@@ -420,6 +444,7 @@ class Expression(_BaseGrammar):
         self.ast = {"Expression": ast}
         self.value = value
 
+
 class List(_BaseGrammar):
     grammar_whitespace_mode = "optional"
     grammar = L("("), ZERO_OR_MORE(Expression), L(")")
@@ -451,6 +476,7 @@ class List(_BaseGrammar):
                 "args": [elem.ast for elem in self[1].elements[1:]],
             }}
 
+
 class SymbolList(_BaseGrammar):
     grammar_whitespace_mode = "optional"
     grammar = L("'("), ZERO_OR_MORE(Expression), L(")")
@@ -459,6 +485,7 @@ class SymbolList(_BaseGrammar):
         self.value = [elem.value for elem in self[1]]
         self.ast = {"SymbolList": [elem.ast for elem in self[1]]}
 
+
 class CurlyList(_BaseGrammar):
     grammar_whitespace_mode = "optional"
     grammar = L("{"), ZERO_OR_MORE(Expression), L("}")
@@ -467,6 +494,7 @@ class CurlyList(_BaseGrammar):
         self.value = {"{}": [elem.value for elem in self[1]]}
         self.ast = {"CurlyList": [elem.ast for elem in self[1]]}
 
+
 class Function(_BaseGrammar):
     grammar_whitespace_mode = "optional"
     grammar = RE(r"[a-zA-Z][a-zA-Z0-9_]*\("), ZERO_OR_MORE(Expression), L(')')
@@ -490,6 +518,7 @@ class Function(_BaseGrammar):
             "args": [elem.ast for elem in self[1]]
         }}
 
+
 class ArrayElement(_BaseGrammar):
     grammar_whitespace_mode = "optional"
     grammar = RE(r"[a-zA-Z][a-zA-Z0-9_]*\["), Expression, L(']')
@@ -502,6 +531,7 @@ class ArrayElement(_BaseGrammar):
             "elem": self[1].ast
         }}
 
+
 class SkillFile(_BaseGrammar):
     grammar_whitespace_mode = "optional"
     grammar = ONE_OR_MORE(Expression), OPTIONAL(WHITESPACE)
@@ -518,7 +548,7 @@ class SkillFile(_BaseGrammar):
             raise Exception("{0}.parser() called directly; use {0}.parse_string()".format(
                 cls.__name__
             ))
-        return super(SkillFile, cls).parser(sessiondata=sessiondata, *args, **kwargs)
+        return super().parser(sessiondata=sessiondata, *args, **kwargs)
 
     @classmethod
     def parse_string(cls, text, *, value4funcs={}, dont_convert=[]):
